Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/Feedback/API.php')
-rw-r--r--plugins/Feedback/API.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/plugins/Feedback/API.php b/plugins/Feedback/API.php
index 70ba272d4d..5915663d4c 100644
--- a/plugins/Feedback/API.php
+++ b/plugins/Feedback/API.php
@@ -24,7 +24,7 @@ use Piwik\Version;
class API extends \Piwik\Plugin\API
{
/**
* Sends feedback for a specific feature to the Piwik team or alternatively to the email address configured in the
* config: "feedback_email_address".
*
* @param string $featureName The name of a feature you want to give feedback to.
@@ -64,15 +64,15 @@ class API extends \Piwik\Plugin\API
{
$feedbackEmailAddress = Config::getInstance()->General['feedback_email_address'];
- $subject = '[ Feedback Feature - Piwik ] ' . $subject;
+ $subject = '[ Feedback Feature - Matomo ] ' . $subject;
$body = Common::unsanitizeInputValue($body) . "\n"
- . 'Piwik ' . Version::VERSION . "\n"
+ . 'Matomo ' . Version::VERSION . "\n"
. 'IP: ' . IP::getIpFromHeader() . "\n"
. 'URL: ' . Url::getReferrer() . "\n";
$mail = new Mail();
$mail->setFrom(Piwik::getCurrentUserEmail());
- $mail->addTo($feedbackEmailAddress, 'Piwik Team');
+ $mail->addTo($feedbackEmailAddress, 'Matomo Team');
$mail->setSubject($subject);
$mail->setBodyText($body);
@$mail->send();
@@ -24,7 +24,7 @@ use Piwik\Version;
{
/**
- * Sends feedback for a specific feature to the Piwik team or alternatively to the email address configured in the
+ * Sends feedback for a specific feature to the Matomo team or alternatively to the email address configured in the
* config: "feedback_email_address".
*